@@ -2,7 +2,7 @@
 from django.test import TestCase
 from django.core.urlresolvers import reverse
 
-import responses
+import httpretty
 
 from pagseguro.settings import NOTIFICATION_URL, CHECKOUT_URL
 from pagseguro.api import PagSeguroItem, PagSeguroApi
@@ -84,7 +84,7 @@ class PagSeguroSignalsTest(TestCase):
             'notificationType': 'transaction'
         }
 
-    @responses.activate
+    @httpretty.activate
     def test_checkout_realizado(self):
         from pagseguro.signals import checkout_realizado
 
@@ -101,8 +101,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.POST,
+        httpretty.register_uri(
+            httpretty.POST,
             CHECKOUT_URL,
             body=checkout_response_xml,
             status=200,
@@ -125,7 +125,7 @@ class PagSeguroSignalsTest(TestCase):
         # load notification
         pagseguro_api.checkout()
 
-    @responses.activate
+    @httpretty.activate
     def test_checkout_realizado_com_sucesso(self):
         from pagseguro.signals import checkout_realizado_com_sucesso
 
@@ -142,8 +142,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.POST,
+        httpretty.register_uri(
+            httpretty.POST,
             CHECKOUT_URL,
             body=checkout_response_xml,
             status=200,
@@ -166,7 +166,7 @@ class PagSeguroSignalsTest(TestCase):
         # load notification
         pagseguro_api.checkout()
 
-    @responses.activate
+    @httpretty.activate
     def test_checkout_realizado_com_erro(self):
         from pagseguro.signals import checkout_realizado_com_erro
 
@@ -183,8 +183,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.POST,
+        httpretty.register_uri(
+            httpretty.POST,
             CHECKOUT_URL,
             body='Unauthorized',
             status=401,
@@ -207,7 +207,7 @@ class PagSeguroSignalsTest(TestCase):
         # load notification
         pagseguro_api.checkout()
 
-    @responses.activate
+    @httpretty.activate
     def test_notificacao_recebida(self):
         from pagseguro.signals import notificacao_recebida
 
@@ -218,8 +218,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml,
             status=200,
@@ -232,7 +232,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @responses.activate
+    @httpretty.activate
     def test_notificacao_status_aguardando(self):
         from pagseguro.signals import notificacao_status_aguardando
 
@@ -243,8 +243,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml,
             status=200,
@@ -257,7 +257,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @responses.activate
+    @httpretty.activate
     def test_notificacao_status_em_analise(self):
         from pagseguro.signals import notificacao_status_em_analise
 
@@ -268,8 +268,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>2</status>'
@@ -284,7 +284,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @responses.activate
+    @httpretty.activate
     def test_notificacao_status_pago(self):
         from pagseguro.signals import notificacao_status_pago
 
@@ -295,8 +295,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>3</status>'
@@ -311,7 +311,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @responses.activate
+    @httpretty.activate
     def test_notificacao_status_disponivel(self):
         from pagseguro.signals import notificacao_status_disponivel
 
@@ -322,8 +322,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>4</status>'
@@ -338,7 +338,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @responses.activate
+    @httpretty.activate
     def test_notificacao_status_em_disputa(self):
         from pagseguro.signals import notificacao_status_em_disputa
 
@@ -349,8 +349,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>5</status>'
@@ -365,7 +365,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @responses.activate
+    @httpretty.activate
     def test_notificacao_status_devolvido(self):
         from pagseguro.signals import notificacao_status_devolvido
 
@@ -376,8 +376,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>6</status>'
@@ -392,7 +392,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @responses.activate
+    @httpretty.activate
     def test_notificacao_status_cancelado(self):
         from pagseguro.signals import notificacao_status_cancelado
 
@@ -403,8 +403,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>7</status>'
@@ -419,11 +419,11 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @responses.activate
+    @httpretty.activate
     def test_update_transaction(self):
         # mock requests
-        responses.add(
-            responses.GET,
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml,
             status=200,
@@ -461,9 +461,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'aguardando')
 
         # mock requests
-        responses.reset()
-        responses.add(
-            responses.GET,
+        httpretty.reset()
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>2</status>'
@@ -491,9 +491,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'em_analise')
 
         # mock requests
-        responses.reset()
-        responses.add(
-            responses.GET,
+        httpretty.reset()
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>3</status>'
@@ -527,9 +527,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'pago')
 
         # mock requests
-        responses.reset()
-        responses.add(
-            responses.GET,
+        httpretty.reset()
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>4</status>'
@@ -569,9 +569,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'disponivel')
 
         # mock requests
-        responses.reset()
-        responses.add(
-            responses.GET,
+        httpretty.reset()
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>5</status>'
@@ -617,9 +617,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'em_disputa')
 
         # mock requests
-        responses.reset()
-        responses.add(
-            responses.GET,
+        httpretty.reset()
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>6</status>'
@@ -671,9 +671,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'devolvido')
 
         # mock requests
-        responses.reset()
-        responses.add(
-            responses.GET,
+        httpretty.reset()
+        httpretty.register_uri(
+            httpretty.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>7</status>'
